==> utils-0.6.0.tgz: package/lib/esm.js <==
import { __spreadArrays } from 'tslib';
import { execSync } from 'child_process';
import chalk from 'chalk';
import spawn from 'cross-spawn';
import open from 'open';
import fs from 'fs';
import path from 'path';
import isGlob from 'is-glob';
import globSync from 'tiny-glob/sync';

// https://github.com/sindresorhus/open#app
var OSX_CHROME = 'google chrome';
var Action;
(function (Action) {
    Action[Action["NONE"] = 0] = "NONE";
    Action[Action["BROWSER"] = 1] = "BROWSER";
    Action[Action["SCRIPT"] = 2] = "SCRIPT";
})(Action || (Action = {}));
function getBrowserEnv() {
    // Attempt to honor this environment variable.
    // It is specific to the operating system.
    // See https://github.com/sindresorhus/open#app for documentation.
    var value = process.env.BROWSER;
    var args = process.env.BROWSER_ARGS
        ? process.env.BROWSER_ARGS.split(' ')
        : [];
    var action;
    if (!value) {
        // Default.
        action = Action.BROWSER;
    }
    else if (value.toLowerCase().endsWith('.js')) {
        action = Action.SCRIPT;
    }
    else if (value.toLowerCase() === 'none') {
        action = Action.NONE;
    }
    else {
        action = Action.BROWSER;
    }
    return { action: action, value: value, args: args };
}
function executeNodeScript(scriptPath, url) {
    var extraArgs = process.argv.slice(2);
    var child = spawn('node', __spreadArrays([scriptPath], extraArgs, [url]), {
        stdio: 'inherit',
    });
    child.on('close', function (code) {
        if (code !== 0) {
            console.log();
            console.log(chalk.red('The script specified as BROWSER environment variable failed.'));
            console.log(chalk.cyan(scriptPath) + " exited with code " + code + ".\n");
        }
    });
    return true;
}
function startBrowserProcess(browser, url, args) {
    // If we're on OS X, the user hasn't specifically
    // requested a different browser, we can try opening
    // Chrome with AppleScript. This lets us reuse an
    // existing tab when possible instead of creating a new one.
    var shouldTryOpenChromeWithAppleScript = process.platform === 'darwin' &&
        (typeof browser !== 'string' || browser === OSX_CHROME);
    if (shouldTryOpenChromeWithAppleScript) {
        try {
            // Try our best to reuse existing tab
            // on OS X Google Chrome with AppleScript
            execSync('ps cax | grep "Google Chrome"');
            execSync('osascript ../openChrome.applescript "' + encodeURI(url) + '"', {
                cwd: __dirname,
                stdio: 'ignore',
            });
            return true;
        }
        catch (_a) {
            // Ignore errors.
        }
    }
    // Another special case: on OS X, check if BROWSER has been set to "open".
    // In this case, instead of passing `open` to `opn` (which won't work),
    // just ignore it (thus ensuring the intended behavior, i.e. opening the system browser):
    // https://github.com/facebook/create-react-app/pull/1690#issuecomment-283518768
    if (process.platform === 'darwin' && browser === 'open') {
        browser = undefined;
    }
    // If there are arguments, they must be passed as array with the browser
    if (typeof browser === 'string' && args.length > 0) {
        browser = __spreadArrays([browser], args);
    }
    // Fallback to open
    // (It will always open new tab)
    // tslint:disable-next-line no-try-promise
    try {
        var options = { app: browser, wait: false };
        // eslint-disable-next-line @typescript-eslint/no-empty-function
        open(url, options).catch(function () { }); // Prevent `unhandledRejection` error.
        return true;
    }
    catch (_b) {
        return false;
    }
}
/**
 * Reads the BROWSER environment variable and decides what to do with it. Returns
 * true if it opened a browser or ran a node.js script, otherwise false.
 */
function openBrowser(url) {
    var _a = getBrowserEnv(), action = _a.action, value = _a.value, args = _a.args;
    switch (action) {
        case Action.NONE:
            // Special case: BROWSER="none" will prevent opening completely.
            return false;
        case Action.SCRIPT:
            return executeNodeScript(value, url);
        case Action.BROWSER:
            return startBrowserProcess(value, url, args);
        default:
            throw new Error('Not implemented.');
    }
}

var _a;
var DEV = 'development';
var PROD = 'production';
var NODE_ENV = (_a = process.env.NODE_ENV, _a === void 0 ? DEV : _a);
var __DEV__ = NODE_ENV === DEV;
var __PROD__ = NODE_ENV === PROD;
var NODE_MODULES_REG = /[/\\]node_modules[/\\]/;
var CWD = process.cwd();
// eslint-disable-next-line node/no-deprecated-api
var EXTENSIONS = __spreadArrays(['.ts', '.tsx'], Object.keys(require.extensions));

var tryPkg = function (pkg) {
    try {
        return require.resolve(pkg);
    }
    catch (_a) { }
};
var tryRequirePkg = function (pkg) {
    try {
        // eslint-disable-next-line @typescript-eslint/no-require-imports, @typescript-eslint/no-unsafe-return
        return require(pkg);
    }
    catch (_a) { }
};
var isPkgAvailable = function (pkg) { return !!tryPkg(pkg); };
var isTsAvailable = isPkgAvailable('typescript');
var isAngularAvailable = isPkgAvailable('@angular/core');
var isMdxAvailable = isPkgAvailable('@mdx/mdx') || isPkgAvailable('@mdx/react');
var isReactAvailable = isPkgAvailable('react');
var isSvelteAvailable = isPkgAvailable('svelte');
var isVueAvailable = isPkgAvailable('vue');
var tryFile = function (filePath, includeDir) {
    if (includeDir === void 0) { includeDir = false; }
    if (typeof filePath === 'string') {
        return fs.existsSync(filePath) &&
            (includeDir || fs.statSync(filePath).isFile())
            ? filePath
            : '';
    }
    for (var _i = 0, _a = filePath || []; _i < _a.length; _i++) {
        var file = _a[_i];
        if (tryFile(file, includeDir)) {
            return file;
        }
    }
    return '';
};
var tryExtensions = function (filepath, extensions) {
    if (extensions === void 0) { extensions = EXTENSIONS; }
    var ext = __spreadArrays(extensions, ['']).find(function (ext) { return tryFile(filepath + ext); });
    return ext == null ? '' : filepath + ext;
};
var tryGlob = function (paths, options) {
    if (options === void 0) { options = {}; }
    var _a = typeof options === 'string' ? { baseDir: options } : options, _b = _a.absolute, absolute = _b === void 0 ? true : _b, _c = _a.baseDir, baseDir = _c === void 0 ? CWD : _c;
    return paths.reduce(function (acc, pkg) {
        return __spreadArrays(acc, (isGlob(pkg)
            ? globSync(pkg, {
                absolute: absolute,
                cwd: baseDir,
            })
            : [tryFile(path.resolve(baseDir, pkg), true)])).filter(Boolean);
    }, []);
};
var identify = function (_) { return !!_; };
var findUp = function (searchEntry, searchFile) {
    if (searchFile === void 0) { searchFile = 'package.json'; }
    console.assert(path.isAbsolute(searchEntry));
    if (!tryFile(searchEntry, true) ||
        (searchEntry !== CWD && !searchEntry.startsWith(CWD + path.sep))) {
        return '';
    }
    searchEntry = path.resolve(fs.statSync(searchEntry).isDirectory()
        ? searchEntry
        : path.resolve(searchEntry, '..'));
    do {
        var searched = tryFile(path.resolve(searchEntry, searchFile));
        if (searched) {
            return searched;
        }
        searchEntry = path.resolve(searchEntry, '..');
    } while (searchEntry === CWD || searchEntry.startsWith(CWD + path.sep));
    return '';
};
var arrayify = function () {
    var args = [];
    for (var _i = 0; _i < arguments.length; _i++) {
        args[_i] = arguments[_i];
    }
    return args.reduce(function (arr, curr) {
        arr.push.apply(arr, (Array.isArray(curr) ? curr : [curr]));
        return arr;
    }, []);
};

var pkg = tryRequirePkg(path.resolve('package.json')) || {};
var lernaConfig = tryRequirePkg(path.resolve('lerna.json')) || {};
var pkgsPath = lernaConfig.packages || pkg.workspaces || [];
var isMonorepo = Array.isArray(pkgsPath) && pkgsPath.length > 0;
var monorepoPkgs = isMonorepo ? tryGlob(pkgsPath) : [];

export { CWD, DEV, EXTENSIONS, NODE_ENV, NODE_MODULES_REG, PROD, __DEV__, __PROD__, arrayify, findUp, identify, isAngularAvailable, isMdxAvailable, isMonorepo, isPkgAvailable, isReactAvailable, isSvelteAvailable, isTsAvailable, isVueAvailable, monorepoPkgs, openBrowser, tryExtensions, tryFile, tryGlob, tryPkg, tryRequirePkg };

==> utils-0.7.0.tgz: package/lib/esm.js <==
import { __spreadArray } from 'tslib';
import { execSync } from 'child_process';
import chalk from 'chalk';
import spawn from 'cross-spawn';
import open from 'open';
import fs from 'fs';
import path from 'path';
import isGlob from 'is-glob';
import globSync from 'tiny-glob/sync';

// based on https://github.com/facebook/create-react-app/blob/master/packages/react-dev-utils/openBrowser.js
// https://github.com/sindresorhus/open#app
var OSX_CHROME = 'google chrome';
var Action;
(function (Action) {
    Action[Action["NONE"] = 0] = "NONE";
    Action[Action["BROWSER"] = 1] = "BROWSER";
    Action[Action["SCRIPT"] = 2] = "SCRIPT";
})(Action || (Action = {}));
function getBrowserEnv() {
    // Attempt to honor this environment variable.
    // It is specific to the operating system.
    // See https://github.com/sindresorhus/open#app for documentation.
    var value = process.env.BROWSER;
    var args = process.env.BROWSER_ARGS
        ? process.env.BROWSER_ARGS.split(' ')
        : [];
    var action;
    if (!value) {
        // Default.
        action = Action.BROWSER;
    }
    else if (value.toLowerCase().endsWith('.js')) {
        action = Action.SCRIPT;
    }
    else if (value.toLowerCase() === 'none') {
        action = Action.NONE;
    }
    else {
        action = Action.BROWSER;
    }
    return { action: action, value: value, args: args };
}
function executeNodeScript(scriptPath, url) {
    var extraArgs = process.argv.slice(2);
    var child = spawn('node', __spreadArray(__spreadArray([scriptPath], extraArgs), [url]), {
        stdio: 'inherit',
    });
    child.on('close', function (code) {
        if (code !== 0) {
            console.log();
            console.log(chalk.red('The script specified as BROWSER environment variable failed.'));
            console.log(chalk.cyan(scriptPath) + " exited with code " + code + ".\n");
        }
    });
    return true;
}
function startBrowserProcess(browser, url, args) {
    // If we're on OS X, the user hasn't specifically
    // requested a different browser, we can try opening
    // Chrome with AppleScript. This lets us reuse an
    // existing tab when possible instead of creating a new one.
    var shouldTryOpenChromeWithAppleScript = process.platform === 'darwin' &&
        (typeof browser !== 'string' || browser === OSX_CHROME);
    if (shouldTryOpenChromeWithAppleScript) {
        try {
            // Try our best to reuse existing tab
            // on OS X Google Chrome with AppleScript
            execSync('ps cax | grep "Google Chrome"');
            execSync('osascript ../openChrome.applescript "' + encodeURI(url) + '"', {
                cwd: __dirname,
                stdio: 'ignore',
            });
            return true;
        }
        catch (_a) {
            // Ignore errors.
        }
    }
    // Another special case: on OS X, check if BROWSER has been set to "open".
    // In this case, instead of passing `open` to `opn` (which won't work),
    // just ignore it (thus ensuring the intended behavior, i.e. opening the system browser):
    // https://github.com/facebook/create-react-app/pull/1690#issuecomment-283518768
    if (process.platform === 'darwin' && browser === 'open') {
        browser = undefined;
    }
    // Fallback to open
    // (It will always open new tab)
    // eslint-disable-next-line sonar/no-try-promise
    try {
        open(url, {
            app: browser
                ? {
                    name: browser,
                    arguments: args,
                }
                : undefined,
            wait: false,
        }).catch(function () { }); // eslint-disable-line @typescript-eslint/no-empty-function -- Prevent `unhandledRejection` error.
        return true;
    }
    catch (_b) {
        return false;
    }
}
/**
 * Reads the BROWSER environment variable and decides what to do with it. Returns
 * true if it opened a browser or ran a node.js script, otherwise false.
 */
function openBrowser(url) {
    var _a = getBrowserEnv(), action = _a.action, value = _a.value, args = _a.args;
    switch (action) {
        case Action.NONE:
            // Special case: BROWSER="none" will prevent opening completely.
            return false;
        case Action.SCRIPT:
            return executeNodeScript(value, url);
        case Action.BROWSER:
            return startBrowserProcess(value, url, args);
        default:
            throw new Error('Not implemented.');
    }
}

var _a;
var DEV = 'development';
var PROD = 'production';
var NODE_ENV = (_a = process.env.NODE_ENV, _a === void 0 ? DEV : _a);
var __DEV__ = NODE_ENV === DEV;
var __PROD__ = NODE_ENV === PROD;
var NODE_MODULES_REG = /[/\\]node_modules[/\\]/;
var CWD = process.cwd();
// eslint-disable-next-line node/no-deprecated-api, sonar/deprecation
var EXTENSIONS = __spreadArray(['.ts', '.tsx'], Object.keys(require.extensions));

var tryPkg = function (pkg) {
    try {
        return require.resolve(pkg);
    }
    catch (_a) { }
};
var tryRequirePkg = function (pkg) {
    try {
        // eslint-disable-next-line @typescript-eslint/no-require-imports, @typescript-eslint/no-unsafe-return
        return require(pkg);
    }
    catch (_a) { }
};
var isPkgAvailable = function (pkg) { return !!tryPkg(pkg); };
var isTsAvailable = isPkgAvailable('typescript');
var isAngularAvailable = isPkgAvailable('@angular/core');
var isMdxAvailable = isPkgAvailable('@mdx/mdx') || isPkgAvailable('@mdx/react');
var isReactAvailable = isPkgAvailable('react');
var isSvelteAvailable = isPkgAvailable('svelte');
var isVueAvailable = isPkgAvailable('vue');
var tryFile = function (filePath, includeDir) {
    if (includeDir === void 0) { includeDir = false; }
    if (typeof filePath === 'string') {
        return fs.existsSync(filePath) &&
            (includeDir || fs.statSync(filePath).isFile())
            ? filePath
            : '';
    }
    for (var _i = 0, _a = filePath || []; _i < _a.length; _i++) {
        var file = _a[_i];
        if (tryFile(file, includeDir)) {
            return file;
        }
    }
    return '';
};
var tryExtensions = function (filepath, extensions) {
    if (extensions === void 0) { extensions = EXTENSIONS; }
    var ext = __spreadArray(__spreadArray([], extensions), ['']).find(function (ext) { return tryFile(filepath + ext); });
    return ext == null ? '' : filepath + ext;
};
var tryGlob = function (paths, options) {
    if (options === void 0) { options = {}; }
    var _a = typeof options === 'string' ? { baseDir: options } : options, _b = _a.absolute, absolute = _b === void 0 ? true : _b, _c = _a.baseDir, baseDir = _c === void 0 ? CWD : _c;
    return paths.reduce(function (acc, pkg) {
        return __spreadArray(__spreadArray([], acc), (isGlob(pkg)
            ? globSync(pkg, {
                absolute: absolute,
                cwd: baseDir,
            })
            : [tryFile(path.resolve(baseDir, pkg), true)])).filter(Boolean);
    }, []);
};
var identify = function (_) { return !!_; };
var findUp = function (searchEntry, searchFile) {
    if (searchFile === void 0) { searchFile = 'package.json'; }
    console.assert(path.isAbsolute(searchEntry));
    if (!tryFile(searchEntry, true) ||
        (searchEntry !== CWD && !searchEntry.startsWith(CWD + path.sep))) {
        return '';
    }
    searchEntry = path.resolve(fs.statSync(searchEntry).isDirectory()
        ? searchEntry
        : path.resolve(searchEntry, '..'));
    do {
        var searched = tryFile(path.resolve(searchEntry, searchFile));
        if (searched) {
            return searched;
        }
        searchEntry = path.resolve(searchEntry, '..');
    } while (searchEntry === CWD || searchEntry.startsWith(CWD + path.sep));
    return '';
};
var arrayify = function () {
    var args = [];
    for (var _i = 0; _i < arguments.length; _i++) {
        args[_i] = arguments[_i];
    }
    return args.reduce(function (arr, curr) {
        arr.push.apply(arr, (Array.isArray(curr) ? curr : curr == null ? [] : [curr]));
        return arr;
    }, []);
};

var pkg = tryRequirePkg(path.resolve('package.json')) || {};
var lernaConfig = tryRequirePkg(path.resolve('lerna.json')) || {};
var pkgsPath = lernaConfig.packages || pkg.workspaces || [];
var isMonorepo = Array.isArray(pkgsPath) && pkgsPath.length > 0;
var monorepoPkgs = isMonorepo ? tryGlob(pkgsPath) : [];

export { CWD, DEV, EXTENSIONS, NODE_ENV, NODE_MODULES_REG, PROD, __DEV__, __PROD__, arrayify, findUp, identify, isAngularAvailable, isMdxAvailable, isMonorepo, isPkgAvailable, isReactAvailable, isSvelteAvailable, isTsAvailable, isVueAvailable, monorepoPkgs, openBrowser, tryExtensions, tryFile, tryGlob, tryPkg, tryRequirePkg };
